]> git.mdlowis.com Git - proto/labwc.git/commitdiff
build: fix name collision with wlroots, when linking statically
authorDima Krasner <dima@dimakrasner.com>
Mon, 8 Nov 2021 18:17:08 +0000 (20:17 +0200)
committerJohan Malm <johanmalm@users.noreply.github.com>
Mon, 8 Nov 2021 19:10:37 +0000 (19:10 +0000)
include/labwc.h
src/subsurface.c
src/view-child.c
src/xdg.c

index b2a4ff7897c9f4a38374b7ad39da4cf5c8f7316f..b45b53e74d547332b69fcca06df7680eef0e5adc 100644 (file)
@@ -342,7 +342,7 @@ void xwayland_unmanaged_create(struct server *server,
 void view_child_init(struct view_child *child, struct view *view,
        struct wlr_surface *wlr_surface);
 void view_child_finish(struct view_child *child);
-void subsurface_create(struct view *view, struct wlr_subsurface *wlr_subsurface);
+void view_subsurface_create(struct view *view, struct wlr_subsurface *wlr_subsurface);
 
 void view_set_activated(struct view *view, bool activated);
 struct border view_border(struct view *view);
index b37cabda7f7e8d90497491b16849c575ad396942..79866355e42e9bf113ebbeac51217d0320c0f1d4 100644 (file)
@@ -21,7 +21,7 @@ subsurface_handle_destroy(struct wl_listener *listener, void *data)
 }
 
 void
-subsurface_create(struct view *view, struct wlr_subsurface *wlr_subsurface)
+view_subsurface_create(struct view *view, struct wlr_subsurface *wlr_subsurface)
 {
        struct view_subsurface *subsurface =
                calloc(1, sizeof(struct view_subsurface));
index dbb305960a4c0b6143c75585c3a9c212dd30eb12..462a53a4632aa8b10f1bdadb82bfe36bd45a1625 100644 (file)
@@ -19,7 +19,7 @@ view_child_handle_new_subsurface(struct wl_listener *listener, void *data)
        struct view_child *child;
        child = wl_container_of(listener, child, new_subsurface);
        struct wlr_subsurface *wlr_subsurface = data;
-       subsurface_create(child->parent, wlr_subsurface);
+       view_subsurface_create(child->parent, wlr_subsurface);
 }
 
 void
index f9fe005933d98ea68e4b91b706cd86969ce733cd..6ad5b6d6f62dc85e8646d80f2ea96244ecd86d70 100644 (file)
--- a/src/xdg.c
+++ b/src/xdg.c
@@ -4,7 +4,7 @@
 #include "ssd.h"
 
 /*
* xdg_popup_create() and subsurface_create() are only called for the
  * purposes of tracking damage.
  */
 static void
@@ -20,7 +20,7 @@ new_subsurface_notify(struct wl_listener *listener, void *data)
 {
        struct view *view = wl_container_of(listener, view, new_subsurface);
        struct wlr_subsurface *wlr_subsurface = data;
-       subsurface_create(view, wlr_subsurface);
+       view_subsurface_create(view, wlr_subsurface);
 }
 
 static bool
@@ -337,11 +337,11 @@ xdg_toplevel_view_map(struct view *view)
                struct wlr_subsurface *subsurface;
                wl_list_for_each(subsurface, &view->surface->current.subsurfaces_below,
                                 current.link) {
-                       subsurface_create(view, subsurface);
+                       view_subsurface_create(view, subsurface);
                }
                wl_list_for_each(subsurface, &view->surface->current.subsurfaces_above,
                                 current.link) {
-                       subsurface_create(view, subsurface);
+                       view_subsurface_create(view, subsurface);
                }
 
                view->been_mapped = true;
@@ -4,7 +4,7 @@
 
 /*
- * xdg_popup_create() and subsurface_create() are only called for the
+ * xdg_popup_create() and view_subsurface_create() are only called for the
  * purposes of tracking damage.
  */